@@ -484,7 +484,7 @@ static void _get_current_debug(GtkRadioAction *action)
 	if (!debug_action)
 		debug_action = gtk_action_group_get_action(
 			menu_action_group, "debug_quiet");
-	/* Since this is the inital value we don't signal anything
+	/* Since this is the initial value we don't signal anything
 	   changed so we need to make it happen here */
 	if (debug_level == 0)
 		debug_inited = 1;
@@ -1056,7 +1056,7 @@ static void _get_info_tabs(GtkTable *table, display_data_t *display_data)
 
 }
 
-extern void _change_cluster_main(GtkComboBox *combo, gpointer extra)
+static void _change_cluster_main(GtkComboBox *combo, gpointer extra)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -1434,8 +1434,9 @@ int main(int argc, char **argv)
 
 	if (!getenv("SLURM_BITSTR_LEN"))
 		setenv("SLURM_BITSTR_LEN", "128", 1);	/* More array info */
-	slurm_conf_init(NULL);
+	slurm_init(NULL);
 	log_init(argv[0], lopts, SYSLOG_FACILITY_USER, NULL);
+
 	load_defaults();
 	cluster_flags = slurmdb_setup_cluster_flags();
 	cluster_dims = slurmdb_setup_cluster_dims();
